===============================
kiek
===============================


.. image:: https://img.shields.io/pypi/v/kiek.svg
        :target: https://pypi.python.org/pypi/kiek
        :alt: pypi

.. image:: https://img.shields.io/travis/maartenq/kiek.svg
        :target: https://travis-ci.org/maartenq/kiek
        :alt: build

.. image:: https://codecov.io/gh/maartenq/kiek /branch/master/graph/badge.svg
        :target: https://codecov.io/gh/maartenq/kiek
        :alt: codecov

.. image:: https://readthedocs.org/projects/kiek/badge/?version=latest
        :target: https://kiek.readthedocs.io/en/latest/?badge=latest
        :alt: docs

.. image:: https://pyup.io/repos/github/maartenq/kiek/shield.svg
         :target: https://pyup.io/repos/github/maartenq/kiek/
         :alt: pyup


A KISS Kiekshow App

* GitHub: https://github.com/maartenq/kiek

* Free software: ISC license
* PyPi: https://pypi.python.org/pypi/kiek
* Documentation: https://kiek.readthedocs.io.
* Travis CI: https://travis-ci.org/maartenq/kiek
* Codecov: https://codecov.io/github/maartenq/kiek


Features
--------

* TODO
